==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/ko.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "서클",
    "Circles' files" : "서클 파일",
    "Select circles to filter by" : "필터할 서클 선택",
    "No circles found" : "서클을 찾을 수 없음",
    "Please select circles to filter by" : "필터할 서클 선택",
    "No files found for the selected circles" : "선택한 서클의 파일을 찾을 수 없음",
    "You created the circle {circle}" : "여러분이 {circle} 서클을 생성함",
    "{author} created the circle {circle}" : "{author} 님이 {circle} 서클을 생성함",
    "You deleted {circle}" : "여러분이 {circle}을(를) 삭제함",
    "{author} deleted {circle}" : "{author} 님이 {circle}을(를) 삭제함",
    "You linked {group} to {circle}" : "여러분이 {group} 그룹을 {circle}에 연결함",
    "{group} has been linked to {circle} by {author}" : "{author} 님이 {group} 그룹을 {circle}에 연결함}",
    "You unlinked {group} from {circle}" : "여러분이 {group} 그룹을 {circle}에서 연결 해제함",
    "{group} has been unlinked from {circle} by {author}" : "{author} 님이 {group} 그룹을 {circle}에서 연결 해제함",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "여러분이 {circle}에 연결된 {group} 그룹의 단계를 %1$s(으)로 변경함",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} 님이 {circle}에 연결된 {group} 그룹의 단계를 %1$s(으)로 변경함",
    "You sent a request to link {circle} with {remote}" : "여러분이 {circle}을(를) {remote}와(과) 연결하는 요청을 보냄",
    "{author} sent a request to link {circle} with {remote}" : "{author} 님이 {circle}을(를) {remote}와(과) 연결하는 요청을 보냄",
    "{remote} requested a link with {circle}" : "{remote}에서 {circle}와(과) 연결 요청함",
    "The request to link {circle} with {remote} has been rejected" : "{circle}와(과) {remote} 연결 요청이 거부됨",
    "The request to link {remote} with {circle} has been canceled remotely" : "{remote}에서 보낸 {circle}와(과) 연결 요청을 원격지에서 거부함",
    "The request to link {circle} with {remote} has been accepted" : "{circle}을(를) {remote}에 연결하는 요청이 수락됨",
    "You dismissed the request to link {remote} with {circle}" : "{circle}을(를) {remote}에 연결하는 요청을 삭제함",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} 님이 {circle}을(를) {remote}에 연결하는 요청을 삭제함",
    "You canceled the request to link {circle} with {remote}" : "여러분이 {circle}을(를) {remote}(으)로 연결하는 요청을 취소함",
    "{author} canceled the request to link {circle} with {remote}" : "{author} 님이 {circle}을(를) {remote}(으)로 연결하는 요청을 취소함",
    "You accepted the request to link {remote} with {circle}" : "{remote}와(과) {circle} 연결 요청을 수락함",
    "{author} accepted the request to link {remote} with {circle}" : "{author} 님이 {remote}와(과) {circle} 연결 요청을 수락함",
    "A link between {circle} and {remote} is now up and running" : "{circle}와(과) {remote} 연결이 활성화되었고 실행 중",
    "The link between {circle} and {remote} has been shutdown remotely" : "{circle}와(과) {remote} 연결을 원격지에서 종료함",
    "You closed the link between {circle} and {remote}" : "여러분이 {circle}와(과) {remote} 연결을 종료함",
    "{author} closed the link between {circle} and {remote}" : "{author} 님이 {circle}와(과) {remote} 연결을 종료함",
    "You joined {circle}" : "여러분이 {circle}에 참가함",
    "{member} joined {circle}" : "{member} 님이 {circle}에 참가함",
    "You accepted the invitation to join {circle}" : "여러분이 {circle}에 등록할 초대장을 수락함",
    "{member} accepted the invitation to join {circle}" : "{member} 님이 {circle}에 등록할 초대장을 수락함",
    "You added {member} as member to {circle}" : "여러분이 {member} 님을 {circle}의 회원으로 추가함",
    "You have been added as member to {circle} by {author}" : "{author} 님이 여러분을 {circle}의 회원으로 추가함",
    "{member} has been added as member to {circle} by {author}" : "{author} 님이 {member} 님을 {circle}의 회원으로 추가함",
    "You added {external} to {circle}" : "여러분이 {external}을(를) {circle}에 추가함",
    "{external} has been added to {circle} by {author}" : "{author} 님이 {external}을(를) {circle}에 추가함",
    "You accepted {member}'s request to join {circle}" : "여러분이 {member} 님의 {circle} 가입 요청을 수락함",
    "Your request to join {circle} has been accepted by {author}" : "{author} 님이 여러분의 {circle} 가입 요청을 수락함",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} 님이 {member} 님의 {circle} 가입 요청을 수락함",
    "You left {circle}" : "여러분이 {circle}을 떠남",
    "{member} left {circle}" : "{member} 님이 {circle}을(를) 떠남",
    "You declined the invitation to join {circle}" : "여러분이 {circle}에 등록할 초대장을 거절함",
    "{member} declined an invitation to join {circle}" : "{member} 님이 {circle}에 등록할 초대장을 거절함",
    "You cancelled your request to join {circle}" : "여러분이 {circle} 가입 요청을 취소함",
    "{member} cancelled his request to join {circle}" : "{member} 님이 {circle} 가입 요청을 취소함",
    "You removed {member} from {circle}" : "여러분이 {member} 님을 {circle}에서 삭제함",
    "You have been removed from {circle} by {author}" : "{author} 님이 여러분을 {circle}에서 삭제함",
    "{member} has been removed from {circle} by {author}" : "{author} 님이 {member} 님을 {circle}에서 삭제함",
    "You removed {external} from {circle}" : "여러분이 {external}을(를) {circle}에서 삭제함",
    "{external} has been removed from {circle} by {author}" : "{author} 님이 {external}을(를) {circle}에서 삭제함",
    "You cancelled {member}'s invitation to join {circle}" : "여러분이 {member} 님의 {circle} 가입 요청을 취소함",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} 님이 여러분의 {circle} 가입 요청을 취소함",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} 님이 {member} 님의 {circle} 가입 요청을 취소함",
    "You dismissed {member}'s request to join {circle}" : "{member} 님의 {circle} 가입 요청을 삭제함",
    "Your request to join {circle} has been dismissed by {author}" : "{author} 님이 여러분의 {circle} 가입 요청을 삭제함",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} 님이 {member} 님의 {circle} 가입 요청을 삭제함",
    "You invited {member} to join {circle}" : "여러분이 {circle}에 {member} 님을 초대함",
    "You have been invited to join {circle} by {author}" : "{author} 님이 여러분을 {circle}에 초대함",
    "{member} has been invited to join {circle} by {author}" : "{author} 님이 {member} 님을 {circle}에 초대함",
    "You changed {member}'s level in {circle} to %1$s" : "여러분이 {circle}의 {member}의 단계를 %1$s(으)로 변경함",
    "{author} changed your level in {circle} to %1$s" : "{author} 님이 {circle}의 내 단계를 %1$s(으)로 변경함",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} 님이 {circle}의 {member}의 단계를 %1$s(으)로 변경함",
    "You sent a request to join {circle}" : "여러분이 {circle} 가입 요청을 보냄",
    "{member} sent a request to join {circle}" : "{member} 님이 {circle} 가입 요청을 보냄",
    "You are the new owner of {circle}" : "여러분이 {circle}의 새 소유자가 됨",
    "{member} is the new owner of {circle}" : "{member} 님이 {circle}의 새 소유자가 됨",
    "Any important event in a <strong>Circle</strong> you are moderating" : "관리하는 <strong>서클</strong>의 중요한 이벤트",
    "Personal" : "개인",
    "System" : "시스템",
    "Visible" : "보임",
    "Open" : "열기",
    "Hidden" : "숨겨짐",
    "Local" : "로컬",
    "Root" : "루트",
    "Federated" : "연합",
    "Contact" : "연락처",
    "Circle" : "서클",
    "Member" : "회원",
    "Moderator" : "중재자",
    "Admin" : "관리자",
    "Owner" : "소유자",
    "%s shared »%s« with you." : "%s 님이 \"%s\"을(를) 공유했습니다.",
    "%s on %s" : "%s(%s의)",
    "Password to access »%s«" : "%s에 접근할 수 있는 암호",
    "It is protected with the following password:" : "비밀번호로 보호됩니다.",
    "%1$s via %2$s" : "%1$s(%2$s 경유)",
    "Click the button below to open it." : "아래 단추를 눌러서 열 수 있습니다.",
    "Open »%s«" : "%s 열기",
    "Circle not found" : "서클을 찾을 수 없음",
    "A circle with that name exists" : "같은 이름의 서클이 이미 존재함",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "시스템 관리자가 서클 형식을 허용하지 않는 한 서클 앱을 사용할 수 없습니다",
    "This member does not exist" : "이 회원이 존재하지 않음",
    "Federated link not found" : "연합 연결을 찾을 수 없음",
    "This feature is not available for personal circles" : "이 기능은 개인 서클에서 사용할 수 없음",
    "The circle is not federated" : "연합 서클이 아님",
    "You cannot join this circle" : "이 서클에 등록할 수 없음",
    "This member is not a moderator" : "이 회원은 중재자가 아님",
    "Insufficient privileges" : "권한이 부족함",
    "This member is the owner of the circle" : "이 회원은 서클 소유자임",
    "Level cannot be changed for this type of member" : "이 회원의 단계를 변경할 수 없음",
    "You are already a member of this circle" : "이미 서클 회원임",
    "You have been blocked from this circle" : "이 서클에서 차단됨",
    "Accept" : "수락",
    "%s" : "%s",
    "Personal Circle" : "개인 서클",
    "You need a specify a type of circle" : "서클 형식을 지정해야 함",
    "This member is not the owner of the circle" : "이 회원은 서클 소유자가 아님",
    "This member is not an admin of the circle" : "이 회원은 서클 관리자가 아님",
    "This group does not exist" : "이 그룹이 존재하지 않음",
    "This group is already linked to the circle" : "이 그룹이 서클에 이미 연결됨",
    "You cannot edit level in a personal circle" : "개인 서클의 단계를 편집할 수 없음",
    "Group cannot be set as owner of a circle" : "그룹을 서클 소유자로 설정할 수 없음",
    "now" : "현재",
    "Email format is not valid" : "이메일 주소가 올바르지 않음",
    "This contact is not available" : "이 연락처를 사용할 수 없음",
    "Could not find share" : "공유를 찾을 수 없음",
    "Bring cloud-users closer together." : "클라우드 사용자를 더 가깝게 연결합니다.",
    "No files in here" : "여기에 파일 없음",
    "No entries found in this folder" : "이 폴더에서 항목을 찾을 수 없음",
    "Name" : "이름",
    "Size" : "크기",
    "Modified" : "수정한 날짜",
    "This user is already a member of the circle" : "이 사용자가 이미 서클 회원임",
    "The user is already a member of this circle" : "이 사용자가 이미 서클 회원임",
    "The user has already been invited into this circle" : "이 사용자를 이미 서클에 초대함",
    "This user does not exist" : "이 사용자가 존재하지 않음"
},
"nplurals=1; plural=0;");

==> nextcloud-31.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/ko.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "{circle} 팀을 생성했습니다.",
    "{author} created the team {circle}" : "유저 {author}이/가 팀  {circle}을 생성했습니다.",
    "You deleted {circle}" : "여러분이 {circle}을(를) 삭제함",
    "{author} deleted {circle}" : "{author} 님이 {circle}을(를) 삭제함",
    "You made {member} join {circle}" : "{member}를 {circle}에 할당했습니다.",
    "{author} made {member} join {circle}" : "유저 {author}이/가 {member}를 {circle}에 할당했습니다.",
    "You removed {member} from {circle}" : "여러분이 {member} 님을 {circle}에서 삭제함",
    "You joined {circle}" : "여러분이 {circle}에 참가함",
    "{member} joined {circle}" : "{member} 님이 {circle}에 참가함",
    "You accepted the invitation to join {circle}" : "여러분이 {circle}에 등록할 초대장을 수락함",
    "{member} accepted the invitation to join {circle}" : "{member} 님이 {circle}에 등록할 초대장을 수락함",
    "You added {member} as member to {circle}" : "여러분이 {member} 님을 {circle}의 회원으로 추가함",
    "You have been added as member to {circle} by {author}" : "{author} 님이 여러분을 {circle}의 회원으로 추가함",
    "{member} has been added as member to {circle} by {author}" : "{author} 님이 {member} 님을 {circle}의 회원으로 추가함",
    "You added {external} to {circle}" : "여러분이 {external}을(를) {circle}에 추가함",
    "{external} has been added to {circle} by {author}" : "{author} 님이 {external}을(를) {circle}에 추가함",
    "You accepted {member}'s request to join {circle}" : "여러분이 {member} 님의 {circle} 가입 요청을 수락함",
    "Your request to join {circle} has been accepted by {author}" : "{author} 님이 여러분의 {circle} 가입 요청을 수락함",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} 님이 {member} 님의 {circle} 가입 요청을 수락함",
    "You left {circle}" : "여러분이 {circle}을 떠남",
    "{member} left {circle}" : "{member} 님이 {circle}을(를) 떠남",
    "You declined the invitation to join {circle}" : "여러분이 {circle}에 등록할 초대장을 거절함",
    "{member} declined an invitation to join {circle}" : "{member} 님이 {circle}에 등록할 초대장을 거절함",
    "You cancelled your request to join {circle}" : "여러분이 {circle} 가입 요청을 취소함",
    "You have been removed from {circle} by {author}" : "{author} 님이 여러분을 {circle}에서 삭제함",
    "{member} has been removed from {circle} by {author}" : "{author} 님이 {member} 님을 {circle}에서 삭제함",
    "You removed {external} from {circle}" : "여러분이 {external}을(를) {circle}에서 삭제함",
    "{external} has been removed from {circle} by {author}" : "{author} 님이 {external}을(를) {circle}에서 삭제함",
    "You cancelled {member}'s invitation to join {circle}" : "여러분이 {member} 님의 {circle} 가입 요청을 취소함",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} 님이 여러분의 {circle} 가입 요청을 취소함",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} 님이 {member} 님의 {circle} 가입 요청을 취소함",
    "You dismissed {member}'s request to join {circle}" : "{member} 님의 {circle} 가입 요청을 삭제함",
    "Your request to join {circle} has been dismissed by {author}" : "{author} 님이 여러분의 {circle} 가입 요청을 삭제함",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} 님이 {member} 님의 {circle} 가입 요청을 삭제함",
    "You invited {member} to join {circle}" : "여러분이 {circle}에 {member} 님을 초대함",
    "You have been invited to join {circle} by {author}" : "{author} 님이 여러분을 {circle}에 초대함",
    "{member} has been invited to join {circle} by {author}" : "{author} 님이 {member} 님을 {circle}에 초대함",
    "You changed {member}'s level in {circle} to %1$s" : "여러분이 {circle}의 {member}의 단계를 %1$s(으)로 변경함",
    "{author} changed your level in {circle} to %1$s" : "{author} 님이 {circle}의 내 단계를 %1$s(으)로 변경함",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} 님이 {circle}의 {member}의 단계를 %1$s(으)로 변경함",
    "You sent a request to join {circle}" : "여러분이 {circle} 가입 요청을 보냄",
    "{member} sent a request to join {circle}" : "{member} 님이 {circle} 가입 요청을 보냄",
    "You are the new owner of {circle}" : "여러분이 {circle}의 새 소유자가 됨",
    "{member} is the new owner of {circle}" : "{member} 님이 {circle}의 새 소유자가 됨",
    "Personal" : "개인",
    "System" : "시스템",
    "Visible" : "보임",
    "Open" : "열기",
    "Invite" : "초대",
    "Friends" : "친구",
    "Password protected" : "암호로 보호됨",
    "No Owner" : "소유자 없음",
    "Hidden" : "숨겨짐",
    "Backend" : "백엔드",
    "Local" : "로컬",
    "Root" : "루트",
    "Federated" : "연합",
    "Nextcloud Account" : "Nextcloud 계정",
    "Nextcloud Group" : "Nextcloud 그룹",
    "Email address" : "이메일 주소",
    "Contact" : "연락처",
    "Circle" : "서클",
    "Nextcloud App" : "Nextcloud 앱",
    "Member" : "회원",
    "Moderator" : "중재자",
    "Admin" : "관리자",
    "Owner" : "소유자",
    "%s shared »%s« with you." : "%s 님이 \"%s\"을(를) 공유했습니다.",
    "%s shared »%s« with \"%s\"." : "%s님이 »%s«을(를) \"%s\"와(과) 공유했습니다.",
    "%s on %s" : "%s(%s의)",
    "Password to access »%s«" : "%s에 접근할 수 있는 암호",
    "It is protected with the following password:" : "다음 암호로 보호됩니다:",
    "%1$s via %2$s" : "%1$s(%2$s 경유)",
    "Click the button below to open it." : "아래 단추를 눌러서 열 수 있습니다.",
    "Open »%s«" : "%s 열기",
    "Password to access files shared to you by %1$s" : "%1$s님이 공유한 파일에 접근하기 위한 암호",
    "Password to access files" : "파일에 접근하기 위한 암호",
    "%s shared multiple files with \"%s\"." : "%s님이 \"%s\"와(과) 여러 파일을 공유했습니다.",
    "%s shared multiple files with you." : "%s님이 여러 파일을 공유했습니다.",
    "Testing Basic Circle Creation" : "기본 서클 생성 테스트 중",
    "Adding local users and moderators" : "로컬 사용자와 중재자 추가 중",
    "Files" : "파일",
    "This feature is not available for personal circles" : "이 기능은 개인 서클에서 사용할 수 없음",
    "This member is not a moderator" : "이 회원은 중재자가 아님",
    "Insufficient privileges" : "권한이 부족함",
    "This member does not exist" : "이 회원이 존재하지 않음",
    "Level cannot be changed for this type of member" : "이 회원의 단계를 변경할 수 없음",
    "You are already a member of this circle" : "이미 서클 회원임",
    "You have been blocked from this circle" : "이 서클에서 차단됨",
    "The account is already a member of this circle" : "이 계정은 이미 이 서클의 회원임",
    "The account has already been invited into this circle" : "이 계정을 이미 이 서클에 초대함",
    "Accept" : "수락",
    "%s" : "%s",
    "%s owned by %s" : "%s이(가) 소유한 %s",
    "%s shared a file with \"%s\"." : "%s님이 \"%s\"에게 파일을 공유했습니다.",
    "%s shared a file with you." : "%s님이 파일을 공유했습니다.",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s님이 공유한 것이 있습니다. \n함께 발송한 별도의 이메일에서 링크를 눌러 이 공유에 접근하십시오.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s님이 공유한 것이 있습니다.\n함께 발송한 별도의 이메일에서 링크를 눌로 이 공유에 접근하십시오.",
    "Password to access content shared with you by %1$s" : "%1$s님의 공유에 접근하기 위한 암호",
    "Bring cloud-users closer together." : "클라우드 사용자를 더 가깝게 연결합니다.",
    "No files in here" : "여기에 파일 없음",
    "No entries found in this folder" : "이 폴더에서 항목을 찾을 수 없음",
    "Name" : "이름",
    "Size" : "크기",
    "Modified" : "수정한 날짜",
    "Shared to Circles" : "서클에 공유됨",
    "You are now a member of the Circle \"%2$s\"" : "당신은 이제 서클 \"%2$s\"의 회원입니다.",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s님이 당신을 서클 \"%2$s\"에 초대했습니다.",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s님이 당신에게 서클 \"%2$s\"의 회원이 될 것을 요청했습니다.",
    "Leave the circle" : "서클 떠나기"
},
"nplurals=1; plural=0;");
